# Build Rules

<!-- Generated file, do not edit directly. -->


Build Rules provided by Apple Support.

<!-- BEGIN_TOC -->
On this page:

  * [apple_genrule](#apple_genrule)
<!-- END_TOC -->

<a name="apple_genrule"></a>
## apple_genrule

<pre style="white-space: normal">
apple_genrule(<a href="#apple_genrule.name">name</a>, <a href="#apple_genrule.cmd">cmd</a>, <a href="#apple_genrule.executable">executable</a>=False, <a href="#apple_genrule.outs">outs</a>=[], <a href="#apple_genrule.srcs">srcs</a>=[], <a href="#apple_genrule.message">message</a>=None, <a href="#apple_genrule.tools">tools</a>=[],
<a href="#apple_genrule.no_sandbox">no_sandbox</a>=False, <a href="#apple_genrule.**kwargs">**kwargs</a>)
</pre>

Genrule which provides Apple specific environment and make variables.

This mirrors the native genrule except that it provides a different set of
make variables. This rule will only run on a Mac.

Example of use:

```
load("@build_bazel_apple_support//rules:apple_genrule.bzl", "apple_genrule")

apple_genrule(
    name = "world",
    outs = ["hi"],
    cmd = "touch $@",
)
```

This rule also does location expansion, much like the native genrule.
For example, `$(location hi)` may be used to refer to the output in the
above example.

The set of make variables that are supported for this rule:

* `OUTS`: The outs list. If you have only one output file, you can also use
          `$@`.
* `SRCS`: The srcs list (or more precisely, the pathnames of the files
          corresponding to labels in the srcs list). If you have only one
          source file, you can also use `$<`.
* `<`: srcs, if it's a single file.
* `@`: outs, if it's a single file.
* `@D`: The output directory. If there is only one filename in outs, this
        expands to the directory containing that file. If there are
        multiple filenames, this variable instead expands to the package's
        root directory in the genfiles tree, even if all the generated
        files belong to the same subdirectory.

The following environment variables are added to the rule action:

* `DEVELOPER_DIR`: The base developer directory as defined on Apple
                   architectures, most commonly used in invoking Apple
                   tools such as xcrun.
* `SDKROOT`: The base SDK directory as defined on Apple architectures, most
             commonly used in invoking Apple tools such as xcrun.

<a name="apple_genrule.arguments"></a>
### Arguments

<table class="params-table">
  <colgroup>
    <col class="col-param" />
    <col class="col-description" />
  </colgroup>
  <tbody>
    <tr id="apple_genrule.name">
      <td><code>name</code></td>
      <td><p><code>Required</code></p><p>The name of the target.</p></td>
    </tr>
    <tr id="apple_genrule.cmd">
      <td><code>cmd</code></td>
      <td><p><code>Required</code></p><p>The command to run. Subject the variable substitution.</p></td>
    </tr>
    <tr id="apple_genrule.executable">
      <td><code>executable</code></td>
      <td><p><code>Optional; default is False</code></p><p>Boolean. Declare output to be executable. Setting this flag to
1 means the output is an executable file and can be run using the run
command. The genrule must produce exactly one output in this case.</p></td>
    </tr>
    <tr id="apple_genrule.outs">
      <td><code>outs</code></td>
      <td><p><code>Optional; default is []</code></p><p>A list of files generated by this rule. If the executable flag is
set, outs must contain exactly one label.</p></td>
    </tr>
    <tr id="apple_genrule.srcs">
      <td><code>srcs</code></td>
      <td><p><code>Optional; default is []</code></p><p>A list of inputs for this rule, such as source files to process.</p></td>
    </tr>
    <tr id="apple_genrule.message">
      <td><code>message</code></td>
      <td><p><code>Optional; default is None</code></p><p>A progress message to be reported as the rule runs.</p></td>
    </tr>
    <tr id="apple_genrule.tools">
      <td><code>tools</code></td>
      <td><p><code>Optional; default is []</code></p><p>A list of tool dependencies for this rule, they will be available
when the action is run.</p></td>
    </tr>
    <tr id="apple_genrule.no_sandbox">
      <td><code>no_sandbox</code></td>
      <td><p><code>Optional; default is False</code></p><p>If the sandbox should be disabled when the action is run.</p></td>
    </tr>
    <tr id="apple_genrule.**kwargs">
      <td><code>**kwargs</code></td>
      <td><p>Extra args meant to just be the common rules for all rules
(tags, etc.).</p></td>
    </tr>
  </tbody>
</table>

